@@ -257,7 +257,7 @@ class Results_Clsf_Tabular(Results_Clsf):
         assert 'prob' in df.columns
         assert data.proc.c_dep in df.columns
         self.proc, self.df = data.proc, df
-        super(Results_Clsf_Tabular, self).__init__(data, df['prob'].values, df[data.proc.c_dep].values)
+        super(Results_Clsf_Tabular, self).__init__(df['prob'].values, df[data.proc.c_dep].values)
         # self.df['prob'] = self.probs if self.data.c>2 else self.probs_bin
     # def corr_cat(self): get_corr(self.df, self.proc.c_cat, plot=True)
     # def corr_cont(self): get_corr(self.df, self.proc.c_cont, plot=True)
